# Light Curve Fitting

This package contains tools to fit analytical models to multiband light curves of astronomical transients.

Please read the [documentation](https://griffin-h.github.io/lightcurve_fitting/) and see the included Jupyter notebook [lightcurve_fitting.ipynb](lightcurve_fitting.ipynb) for tips on how to get started.
If you need help after that, feel free to contact the first author for help.

If you use this code in a publication, please **cite the original papers** whose models you used, as well as my Zenodo repository. [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2639463.svg)](https://doi.org/10.5281/zenodo.2639463)
